//This file is part of the GraphWalker java package
//The MIT License
//
//Copyright (c) 2010 graphwalker.org
//
//Permission is hereby granted, free of charge, to any person obtaining a copy
//of this software and associated documentation files (the "Software"), to deal
//in the Software without restriction, including without limitation the rights
//to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//copies of the Software, and to permit persons to whom the Software is
//furnished to do so, subject to the following conditions:
//
//The above copyright notice and this permission notice shall be included in
//all copies or substantial portions of the Software.
//
//THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//THE SOFTWARE.

package org.graphwalker.conditions;

import org.apache.log4j.Logger;
import org.graphwalker.Util;
import org.graphwalker.exceptions.StopConditionException;

public class EdgeCoverage extends StopCondition {

	private double limit;
	static Logger logger = Util.setupLogger(EdgeCoverage.class);

	public EdgeCoverage() throws StopConditionException {
		this(1);
	}

	public EdgeCoverage(double limit) throws StopConditionException {
		if (limit > 1 || limit < 0)
			throw new StopConditionException("Excpeted an edge coverage between 0 and 100. Actual: " + limit * 100);
		this.limit = limit;
	}

	@Override
	public boolean isFulfilled() {
		double edges = machine.getAllEdges().size();
		double covered = machine.getNumOfCoveredEdges();
		logger.debug("Edges/covered (limit): " + edges + "/" + covered + " (" + limit + ")");
		return (covered / edges) >= limit;
	}

	@Override
	public double getFulfilment() {
		double edges = machine.getAllEdges().size();
		double covered = machine.getNumOfCoveredEdges();
		return (covered / edges) / limit;
	}

	@Override
	public String toString() {
		return "EC>=" + (int) (100 * limit);
	}

}
